@@ -17,7 +17,10 @@
 typedef int (* error_handler_t) (const char * source_file,
                                  int source_line_number,
                                  const char * message, ...)
-    __attribute__((format (printf, 3, 4)));
+#ifdef __GNUC__
+    __attribute__((format (printf, 3, 4)))
+#endif /* __GNUC__ */
+;
 #endif /* ndef ERROR_HANDLER_H */
 
 extern error_handler_t text_fuzzy_error_handler;
@@ -138,6 +141,8 @@ End:
 
 #ifdef HEADER
 
+/* This structure contains one string of whatever type. */
+
 typedef struct text_fuzzy_string {
     char * text;
     int length;
@@ -146,6 +151,10 @@ typedef struct text_fuzzy_string {
 }
 text_fuzzy_string_t;
 
+/* This string contains one string plus additional paraphenalia used
+   in searching for the string, for example the alphabet of the
+   string. */
+
 typedef struct text_fuzzy {
     /* The string we are to match. */
     text_fuzzy_string_t text;
@@ -173,11 +182,15 @@ text_fuzzy_t;
 
 #endif /* HEADER */
 
+/* Compare tf and b. */
+
 FUNC (compare_single) (text_fuzzy_t * tf,
                        text_fuzzy_string_t * b)
 {
+
     /* The edit distance between "tf->search_term" and the
        truncated version of "tf->buf". */
+
     int d;
 
     tf->found = 0;
@@ -207,11 +220,11 @@ FUNC (compare_single) (text_fuzzy_t * tf,
             b->ulength = b->length;
         }
         if (tf->max_distance >= 0) {
-        /* If the distance in the length of the strings is greater
-           than the max distance, give up. */
-        if (abs (tf->text.ulength - b->ulength) > tf->max_distance) {
-            OK;
-        }
+	    /* If the distance in the length of the strings is greater
+	       than the max distance, give up. */
+	    if (abs (tf->text.ulength - b->ulength) > tf->max_distance) {
+		OK;
+	    }
         }
         d = distance_int (b->unicode, b->ulength, tf);
         if (allocated) {
@@ -221,6 +234,8 @@ FUNC (compare_single) (text_fuzzy_t * tf,
     }
     else {
 
+	/* This is not Unicode. */
+
         if (tf->max_distance >= 0) {
             /* If the distance in the length of the strings is greater
                than the max distance, give up. */
@@ -240,6 +255,9 @@ FUNC (compare_single) (text_fuzzy_t * tf,
                     if (! tf->alphabet[a]) {
                         alphabet_misses++;
                         if (alphabet_misses > tf->max_distance) {
+			    /* It is not possible that the two words
+			       are within the maximum edit distance of
+			       each other. */
                             OK;
                         }
                     }
@@ -257,6 +275,11 @@ FUNC (compare_single) (text_fuzzy_t * tf,
     OK;
 }
 
+/* This is the threshold above which we do not bother computing the
+   alphabet of the string. If it has more than this number of unique
+   characters, the alphabet will not reduce the search time by
+   much. */
+
 static int max_unique_characters = 45;
 
 /* Generate an alphabet from the search word, which is used to filter
@@ -288,6 +311,14 @@ FUNC (generate_alphabet) (text_fuzzy_t * text_fuzzy)
     OK;
 }
 
+/*   __ _ _         __                  _   _                 
+    / _(_) | ___   / _|_   _ _ __   ___| |_(_) ___  _ __  ___ 
+   | |_| | |/ _ \ | |_| | | | '_ \ / __| __| |/ _ \| '_ \/ __|
+   |  _| | |  __/ |  _| |_| | | | | (__| |_| | (_) | | | \__ \
+   |_| |_|_|\___| |_|  \__,_|_| |_|\___|\__|_|\___/|_| |_|___/ */
+                                                           
+
+
 #define BUF_SIZE 0x1000
 
 typedef struct fuzzy_file {
@@ -369,6 +400,9 @@ STATIC FUNC (close) (fuzzy_file_t * ff)
     OK;
 }
 
+/* Scan the file specified by "file_name" for our string. The nearest
+   string found is returned in "* nearest_ptr". */
+
 FUNC (scan_file) (text_fuzzy_t * text_fuzzy, char * file_name,
                   char ** nearest_ptr)
 {
